@@ -196,7 +196,7 @@ class Database:
                     err_msg += error + ','
             print(err_msg)
 
-    def get_hk_fut_ohlc(self, index, start_date, end_date, freq, rolling_day, rolling_time, rth_only=False):
+    def get_hk_fut_ohlc(self, index, start_date, end_date, freq, rolling_day, rolling_time = 0, rth_only=False):
         
         check_bool_dict = self.check_hk_fut_ohlc_args(index, freq, start_date, end_date, rolling_day, rolling_time)
 
@@ -1021,6 +1021,7 @@ class Database:
             
             response = requests.get(link_str)
             response_ok = response_check(response)
+
             if response_ok == True:
 
                 result = ast.literal_eval(json.loads(response.content))
@@ -1033,23 +1034,21 @@ class Database:
                         df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
 
                 if index_name == 'hsi_const_hist':
-                    mode = df['end_date'].mode()[0]
+
                     df['is_alive'] = df['is_alive'].astype(bool)
-                    #df['is_delisted'] = df['is_delisted'].astype(bool)
                     df = df.rename(columns={'is_alive':'is_active'})
 
                     for i in range(len(df)):
                         end_date = df.loc[i, 'end_date']
-                        if end_date == mode:
+                        is_active = df.loc[i, 'is_active']
+                        if is_active == True:
                             df.at[i, 'end_date'] = datetime.datetime.now().strftime('%Y-%m-%d')
+
                     for col in df.columns:
                         if col == 'start_date' or col == 'end_date':
                             df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
                     df = df[['code','name','start_date','end_date','is_active']]
 
-                if index_name == 'hk_opt_stocks':
-                    df = df.rename(columns={'ATS_code':'code'})
-
 
                 return df
 
@@ -1111,6 +1110,7 @@ class Database:
         
         response = requests.get(link_str)
         response_ok = response_check(response)
+
         if response_ok == True:
 
             result = ast.literal_eval(json.loads(response.content))
